@@ -5,4 +5,8 @@ __email__ = 'jay3686@gmail.com'
 __version__ = '0.1.1'
 
 
-from .romannumeral import RomanNumeral
\ No newline at end of file
+from .romannumeral import RomanNumeral
+
+from .error import RomanError
+from .error import ParseError
+from .error import OutOfRangeError
\ No newline at end of file
